@@ -3,7 +3,7 @@
   Project: masudoku
   Platform: Fremantle (maemo5)
   Author: Petri Kultanen pete@petnetti.net
-  Last Edit: 15.2.2010
+  Last Edit: 3.6.2010
 */
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
@@ -18,6 +18,7 @@ class QWidget;
 class QPushButton;
 class QLabel;
 class QRadioButton;
+class SudokuSettings;
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
@@ -29,11 +30,13 @@ class MainWindow : public QMainWindow
     void newGame();
     void solveOne();
     void solveTable();
-    void changeSettings();
+    void applySettingsChange();
     void repaintElements();
     void toggleNumberTypes();
     void checkTable();
     void aboutt();
+    void showSettingsDialog();
+	void updateBackground();
 public:
     MainWindow(QWidget *parent = 0);
     ~MainWindow();
@@ -43,6 +46,7 @@ private:
     CSudokuTable *iTable;
     SudokuTableWidget *iTableWidget;
     SudokuSelectNumberWidget *iSelectNumberWidget;
+	SudokuSettings* iSettings;
     QWidget *iMainWidget;
     QPushButton *iNewGameButton;
     QPushButton *iSolveOneButton;
@@ -51,9 +55,9 @@ private:
     QLabel *iSolvableText;
     QRadioButton *iNormalNumberRadioButton;
     QRadioButton *iMarkupNumberRadioButton;
-    bool iSettingAutoCheck;
+
     bool iCriticalError;
-    //bool iPracticeMode;
+
 };
 
 #endif // MAINWINDOW_H
