@@ -3,7 +3,7 @@
   Project: masudoku
   Platform: Fremantle (maemo5)
   Author: Petri Kultanen pete@petnetti.net
-  Last Edit: 15.2.2010
+  Last Edit: 3.6.2010
 */
 #ifndef SUDOKUSELECTNUMBERWIDGET_H
 #define SUDOKUSELECTNUMBERWIDGET_H
@@ -12,6 +12,7 @@
 class CSudokuTable;
 class QPaintEvent;
 class QMouseEvent;
+class SudokuSettings;
 enum NumberTypes
 {
     ENormalNumbers =0,
@@ -25,6 +26,7 @@ public:
     Q_OBJECT
 public:
     void setTable(CSudokuTable *aTable);
+	void setSettings(SudokuSettings* aSettings){iSettings = aSettings;};
     void paintEvent(QPaintEvent *aEvent);
     void mousePressEvent(QMouseEvent * aEvent);
     void setCoordinates(int aX,int aY);
@@ -34,6 +36,7 @@ signals:
     void numberSelected(int aNum);
 private:
     CSudokuTable *iTable;
+	SudokuSettings* iSettings;
     int iX;
     int iY;
     bool iSettingNumberHints;
