@@ -3,7 +3,7 @@
   Project: masudoku
   Platform: Fremantle (maemo5)
   Author: Petri Kultanen pete@petnetti.net
-  Last Edit: 15.2.2010
+  Last Edit: 3.6.2010
 */
 #ifndef SUDOKUTABLE_H
 #define SUDOKUTABLE_H
@@ -52,6 +52,10 @@ public:
     bool setMemoryNumber(int aNum, int aCol,int aRow);
     bool removeMemoryNumber(int aNum, int aCol,int aRow);
     void removeMemoryNumbers(int aCol, int aRow);
+	//For save game
+	qint32 getMemoryDataNum(int aCol,int aRow);
+	void setMemoryDataNum(qint32 aNum, int aCol, int aRow);
+	
 private:
     void copySudokuTableL(CSudokuTable* aTable);
     bool fillRowL();// find correct numbers to table, go thorough all Rows once
