@@ -3,7 +3,7 @@
   Project: masudoku
   Platform: Fremantle (maemo5)
   Author: Petri Kultanen pete@petnetti.net
-  Last Edit: 15.2.2010
+  Last Edit: 3.6.2010
 */
 #ifndef SUDOKUTABLEWIDGET_H
 #define SUDOKUTABLEWIDGET_H
@@ -13,12 +13,14 @@ class CSudokuTable;
 class QPaintEvent;
 class QMouseEvent;
 class QString;
+class SudokuSettings;
 class SudokuTableWidget : public QWidget
 {
     Q_OBJECT
 public:
     SudokuTableWidget();
     void setTable(CSudokuTable *aTable);
+	void setSettings(SudokuSettings* aSettings){iSettings = aSettings;};
     void paintEvent(QPaintEvent *aEvent);
     void mousePressEvent(QMouseEvent * aEvent);
     void setSelectedCoordinates(int aX,int aY);
@@ -27,8 +29,9 @@ signals:
 
 private:
     CSudokuTable *iTable;
-    int iSelectedX; /// used for drawing mark to cell that is being edited.
+    int iSelectedX; // used for drawing mark to cell that is being edited.
     int iSelectedY;
+	SudokuSettings* iSettings;
 };
 
 #endif // SUDOKUTABLEWIDGET_H
